==> tine20-tinebase_2016.11.24.tar.bz2: Addressbook/js/Addressbook-lang-tr_TR-debug.js <==
/********************** tine translations of Addressbook**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/Addressbook'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Turkish (Turkey) (http://www.transifex.com/tine20/tine20/language/tr_TR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: tr_TR\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "İş yeri iltişim bilgileri"

, "Organisation / Unit"
: "Şirket / Bölüm"

, "Business Address"
: "İş adresi"

, "Email"
: "E-Posta"

, "Telephone Work"
: "İş telefonu"

, "Telephone Cellphone"
: "Telefon (Cep)"

, "Telephone Car"
: "Araç telefonu"

, "Telephone Fax"
: "Telefon (Faks)"

, "Telephone Page"
: "Çağrı cihazı"

, "URL"
: "URL"

, "Role"
: "Rol"

, "Room"
: "Oda"

, "Assistant"
: "Asistan"

, "Assistant Telephone"
: "Telefon (Asistan)"

, "Private Contact Data"
: "Özek temas bilgileri"

, "Private Address"
: "Ev adresi"

, "Email Home"
: "E-Posta (Ev)"

, "Telephone Home"
: "Telefon (Ev)"

, "Telephone Cellphone Private"
: "Cep telefonu (Özel)"

, "Telephone Fax Home"
: "Faks"

, "URL Home"
: "URL"

, "Other Data"
: "Diğer bilgi"

, "Birthday"
: "Doğum tarihi"

, "Job Title"
: "Meslek"

, "Dear Mister"
: ""

, "Dear Miss"
: ""

, "Dear"
: ""

, "Mister"
: ""

, "Misses"
: ""

, "%s's personal addressbook"
: "%s in özel adres defteri"

, "Lists"
: "Listeler"

, "List Roles"
: ""

, "manage shared addressbooks"
: "Paylaşılan adres defterlerini yönet"

, "Create new shared addressbook folders"
: "Yeni paylaşılan adresdefteri klasörü oluştur."

, "manage shared addressbook favorites"
: "Sık kullanılan ortak adres defterlerini düzelt"

, "Create or update shared addressbook favorites"
: "Sık kullanılan ortak adres defteri kur veya düzelt"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list roles in CoreData"
: ""

, "View, create, delete or update list roles in CoreData application"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "CardDAV URL"
: "CardDAV adresi"

, "Contact, Contacts"
: [
  "one: Kişi\n\nother: Kişiler"

]
, "List Role, , n); gettext("
: [
  ""

]
, "Members"
: ""

, "Remove Member"
: ""

, "Map"
: "Harita"

, "Personal Information"
: "Şahsi bilgiler"

, "Salutation"
: "Hitap"

, "Title"
: "Ünvan"

, "First Name"
: "İsim"

, "Middle Name"
: "İkincı isim"

, "Last Name"
: "Soy isim"

, "Company"
: "Şirket"

, "Unit"
: "Bölümü"

, "Suffix"
: "Ünvan"

, "Job Role"
: "Görev"

, "Display Name"
: "Görüntülen isim"

, "Contact Information"
: "İletişim bilgileri"

, "Phone"
: "Telefon"

, "Mobile"
: "Cep telefonu"

, "Fax"
: "Faks"

, "Phone (private)"
: "Telefon (Ev)"

, "Mobile (private)"
: "Cep telefonu (Özel)"

, "Fax (private)"
: "Faks (Ev)"

, "E-Mail"
: "E-Posta"

, "E-Mail (private)"
: "E-Posta (Ev)"

, "Web"
: "Web adresi"

, "Company Address"
: "Şirket adresı"

, "Street"
: "Cadde"

, "Street 2"
: "Cadde2"

, "Region"
: "İl"

, "Postal Code"
: "Posta kodu"

, "City"
: "Şehir"

, "Country"
: "Ülke"

, "Description"
: "Açıklama"

, "Enter description"
: "Detaylı bilgi gir"

, "Export as pdf"
: "PDF olarak dışa aktar"

, "Parse address"
: "Adresi oku"

, "Paste address"
: "Adresi yapıştır"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "Son verilmiş özellil modu"

, "New Contact"
: "Yeni İsim"

, "Addressbook, Addressbooks"
: [
  "one: Adres defteri\n\nother: Adres defterleri"

]
, "ID"
: ""

, "Name"
: "İsim"

, "Member of List"
: "Grup üyesi"

, "Street (Company Address)"
: "Adres (Şirket)"

, "Street 2 (Company Address)"
: "Adres2 (Şirket)"

, "City (Company Address)"
: "Şehir (Şirket)"

, "Region (Company Address)"
: "İl (Şirket)"

, "Postal Code (Company Address)"
: "Posta Kodu (Şirket)"

, "Country (Company Address)"
: "Ülke (Şirket)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Cadde (Ev)"

, "Street 2 (Private Address)"
: "Cadde2 (Ev)"

, "City (Private Address)"
: "Şehir (Ev)"

, "Region (Private Address)"
: "İl (Ev)"

, "Postal Code (Private Address)"
: "Posta Kodu (Ev)"

, "Country (Private Address)"
: "Ülke (Ev)"

, "Company Communication"
: "Şirket iletişim"

, "Private Communication"
: "Şahıs iletişim"

, "Web (private)"
: "Web"

, "Contacts"
: "Kişiler"

, "Addressbooks"
: "Adres defterleri"

, "User Account"
: "Kullanıcı hesabı"

, "Quick Search"
: ""

, "Type"
: "Tip"

, "Last Modified Time"
: "Son düzenleme vakti"

, "Last Modified By"
: "Son düzenlemeyi yapan"

, "Creation Time"
: "Oluşturma vakti"

, "Created By"
: "Oluşturan"

, "List, Lists"
: [
  "one: Liste\n\nother: Listeler"

]
, "Quick search"
: ""

, "Email Address, Email Addresses"
: [
  ""

]
, "Email Addresses"
: ""

, "Select list"
: ""

, "List type"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "List Information"
: ""

, "{0} must be given"
: ""

, "Company address"
: "Adres (Şirket)"

, "Private address"
: "Adres (Ev)"

, "Select contact"
: "Kişi seç"

, "Private"
: "Özel"

, "Info"
: "İnfo"

, "Insecure link"
: "Güvensiz adres"

, "Please review this link in edit dialog."
: "Adresi kontrol edin"

, "Export {0}, Export {0}"
: [
  "one: Dışa aktar\n\nother: Dışa aktar"

]
, "Export as PDF"
: "PDF olarak dışa aktar"

, "Export as CSV"
: "CSV olarak dışa aktar"

, "Export as ODS"
: "ODS olarak dışa aktar"

, "Export as XLS"
: "XLS olarak dışa aktar"

, "Export as DOC"
: ""

, "Export as ..."
: "Dışa aktar:"

, "Import contacts"
: "İçe aktar"

, "Contact of a user account"
: "Bir hesabın kişisi"

, "No name"
: ""

, "Tags"
: "Etiketler"

, "Full Name"
: "İsim"

, "Postalcode"
: "Posta kodu"

, "Street (private)"
: "Cadde"

, "City (private)"
: "Şehir"

, "Region (private)"
: "İl"

, "Postalcode (private)"
: "Posta kodu"

, "Country (private)"
: "Ülke"

, "Car phone"
: "Araç telefonu"

, "Pager"
: "Çağrı cihazı"

, "Email (private)"
: "E-Posta (Ev)"

, "URL (private)"
: "URL"

, "Note"
: "Not"

, "Timezone"
: "Zaman dilimi"

, "Geo"
: "Coğrafi yer"

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Uploaded new contact image."
: "Yeni profil resmi yüklenmiştir"

, "All contacts"
: "Tüm kişiler"

, "Default Addressbook"
: "Standart adres defteri"

, "The default addressbook for new contacts"
: "Yeni kişiler için standart adres defteri"

, "Default Favorite"
: "Standart favori"

, "The default favorite which is loaded on addressbook startup"
: "Adres defteri yüklenirken standart favori"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "All Contacts"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee)"
: ""

, "Contact duplicate check fields"
: "Çift-Değer-Kontrolü için temas alanları"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Yeni bir kişi eklendiğinde bu alanlar aktifdir. Şayet iki kişi bir alanda aynı bilgiye sahip olurlar ise, bir hata mesajı görüntülenicektir."

, "Contact salutations available"
: "Mevcut kişi hitapları"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Mümkün olan hitaplar. Sonradan eklenen hitaplar, dişarıya aktırılırken veya bir cihaz ile senkronize edilirken hedefi etkileyebilir."

, "Mr"
: "Bey"

, "Ms"
: "Hanım"

, "Parsing rules for addresses"
: "Adresler için analiz kuralları"

, "Path to a XML file with address parsing rules."
: "Adresler için analiz kurallarına sahip olan XML Dosyasının yolu"

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "Outlook 2007 CSV içe aktar"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Listeyi içeriye aktar (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Kişiler ###CURRENTDATE### Saat ###CURRENTDATE###, ###USERFULLNAME### tarafından eklenmiştir"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Outlook CSV içe aktar"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Kişileri Google den içeriye aktar"

, "Contact CSV import from mac address book"
: "Mac CSV içe aktar"

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "VCARD içe aktar"

, "Internal Contacts"
: "Sistem içi kişiler"

, "All contacts I have read grants for"
: "Okuma hakkına sahip olduğum kişiler"

, "My company"
: "Şirketim"

, "All coworkers in my company"
: "Şirketimdeki iş arkadaşlarım"

, "My contacts"
: "Kişilerim"

, "All contacts in my Addressbooks"
: "Rehberimdeki kişiler"

, "Last modified by me"
: "Son düzenlediğim"

, "All contacts that I have last modified"
: "Son düzenlediğim kişiler"

, "Contact"
: "one: Kişi\n\nother: Kişiler"

, "List Role"
: ""

, "Addressbook"
: "one: Adres defteri\n\nother: Adres defterleri"

, "List"
: "one: Liste\n\nother: Listeler"

, "Email Address"
: ""

, "Export {0}"
: "one: Dışa aktar\n\nother: Dışa aktar"

}));

==> tine20-tinebase_2019.11.25.tar.bz2: Addressbook/js/Addressbook-lang-tr_TR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Turkish (Turkey) (http://www.transifex.com/tine20/tine20/language/tr_TR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: tr_TR\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "İş yeri iltişim bilgileri"

, "Organisation / Unit"
: "Şirket / Bölüm"

, "Business Address"
: "İş adresi"

, "Email"
: "E-Posta"

, "Telephone Work"
: "İş telefonu"

, "Telephone Cellphone"
: "Telefon (Cep)"

, "Telephone Car"
: "Araç telefonu"

, "Telephone Fax"
: "Telefon (Faks)"

, "Telephone Page"
: "Çağrı cihazı"

, "URL"
: "URL"

, "Role"
: "Rol"

, "Room"
: "Oda"

, "Assistant"
: "Asistan"

, "Assistant Telephone"
: "Telefon (Asistan)"

, "Private Contact Data"
: "Özek temas bilgileri"

, "Private Address"
: "Ev adresi"

, "Email Home"
: "E-Posta (Ev)"

, "Telephone Home"
: "Telefon (Ev)"

, "Telephone Cellphone Private"
: "Cep telefonu (Özel)"

, "Telephone Fax Home"
: "Faks"

, "URL Home"
: "URL"

, "Other Data"
: "Diğer bilgi"

, "Birthday"
: "Doğum tarihi"

, "Job Title"
: "Meslek"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  "one: Liste\n\nother: Listeler"
 ,"one: Liste\n\nother: Listeler"

]
, "Percent"
: ""

, "Description"
: "Açıklama"

, "Members"
: ""

, "Type"
: "Tip"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  "one: Adres defteri\n\nother: Adres defterleri"
 ,"one: Adres defteri\n\nother: Adres defterleri"

]
, "Contact, Contacts"
: [
  "one: Kişi\n\nother: Kişiler"
 ,"one: Kişi\n\nother: Kişiler"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "Ülke"

, "City"
: "Şehir"

, "Postalcode"
: "Posta kodu"

, "Region"
: "İl"

, "Street"
: "Cadde"

, "Street 2"
: "Cadde2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Ülke"

, "City (private)"
: "Şehir"

, "Postalcode (private)"
: "Posta kodu"

, "Region (private)"
: "İl"

, "Street (private)"
: "Cadde"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "E-Posta (Ev)"

, "Free/Busy URI"
: ""

, "Geo"
: "Coğrafi yer"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""

]
, "Note"
: "Not"

, "Last Name"
: "Soy isim"

, "Display Name"
: "Görüntülen isim"

, "Full Name"
: "İsim"

, "First Name"
: "İsim"

, "Middle Name"
: "İkincı isim"

, "Title"
: "Ünvan"

, "Suffix"
: "Ünvan"

, "Company"
: "Şirket"

, "Unit"
: "Bölümü"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Görev"

, "Salutation"
: "Hitap"

, "syncBackendIds"
: ""

, "Car phone"
: "Araç telefonu"

, "Mobile"
: "Cep telefonu"

, "Mobile (private)"
: "Cep telefonu (Özel)"

, "Fax"
: "Faks"

, "Fax (private)"
: "Faks (Ev)"

, "Phone (private)"
: "Telefon (Ev)"

, "Pager"
: "Çağrı cihazı"

, "Phone"
: "Telefon"

, "Timezone"
: "Zaman dilimi"

, "Web"
: "Web adresi"

, "URL (private)"
: "URL"

, "Label"
: ""

, "Lists"
: "Listeler"

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "İletişim bilgileri"

, "Company Address"
: "Şirket adresı"

, "New Contact"
: "Yeni İsim"

, "ID"
: ""

, "Name"
: "İsim"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: "İçe aktar"

, "Contact of a user account"
: "Bir hesabın kişisi"

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Özel"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Etiketler"

, "List Roles"
: ""

, "Street (Company Address)"
: "Adres (Şirket)"

, "Street 2 (Company Address)"
: "Adres2 (Şirket)"

, "City (Company Address)"
: "Şehir (Şirket)"

, "Region (Company Address)"
: "İl (Şirket)"

, "Postal Code (Company Address)"
: "Posta Kodu (Şirket)"

, "Country (Company Address)"
: "Ülke (Şirket)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Cadde (Ev)"

, "Street 2 (Private Address)"
: "Cadde2 (Ev)"

, "City (Private Address)"
: "Şehir (Ev)"

, "Region (Private Address)"
: "İl (Ev)"

, "Postal Code (Private Address)"
: "Posta Kodu (Ev)"

, "Country (Private Address)"
: "Ülke (Ev)"

, "Company Communication"
: "Şirket iletişim"

, "Private Communication"
: "Şahıs iletişim"

, "E-Mail"
: "E-Posta"

, "E-Mail (private)"
: "E-Posta (Ev)"

, "Web (private)"
: "Web"

, "Contacts"
: "Kişiler"

, "Addressbooks"
: "Adres defterleri"

, "User Account"
: "Kullanıcı hesabı"

, "Quick Search"
: ""

, "Postal Code"
: "Posta kodu"

, "Last Modified Time"
: "Son düzenleme vakti"

, "Last Modified By"
: "Son düzenlemeyi yapan"

, "Creation Time"
: "Oluşturma vakti"

, "Created By"
: "Oluşturan"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Detaylı bilgi gir"

, "{0} must be given"
: ""

, "Member of List"
: "Grup üyesi"

, "Map"
: "Harita"

, "Company address"
: "Adres (Şirket)"

, "Private address"
: "Adres (Ev)"

, "CardDAV URL"
: "CardDAV adresi"

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Şahsi bilgiler"

, "Parse address"
: "Adresi oku"

, "Print contact"
: ""

, "Paste address"
: "Adresi yapıştır"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "Son verilmiş özellil modu"

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: "Tüm kişiler"

, "Default Addressbook"
: "Standart adres defteri"

, "The default addressbook for new contacts"
: "Yeni kişiler için standart adres defteri"

, "Default Favorite"
: "Standart favori"

, "The default favorite which is loaded on addressbook startup"
: "Adres defteri yüklenirken standart favori"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: "Çift-Değer-Kontrolü için temas alanları"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Yeni bir kişi eklendiğinde bu alanlar aktifdir. Şayet iki kişi bir alanda aynı bilgiye sahip olurlar ise, bir hata mesajı görüntülenicektir."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Mevcut kişi hitapları"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Mümkün olan hitaplar. Sonradan eklenen hitaplar, dişarıya aktırılırken veya bir cihaz ile senkronize edilirken hedefi etkileyebilir."

, "Mr"
: "Bey"

, "Ms"
: "Hanım"

, "Parsing rules for addresses"
: "Adresler için analiz kuralları"

, "Path to a XML file with address parsing rules."
: "Adresler için analiz kurallarına sahip olan XML Dosyasının yolu"

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "VCARD içe aktar"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Listeyi içeriye aktar (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Kişiler ###CURRENTDATE### Saat ###CURRENTDATE###, ###USERFULLNAME### tarafından eklenmiştir"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "Outlook 2007 CSV içe aktar"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Outlook CSV içe aktar"

, "Contact CSV import from mac address book"
: "Mac CSV içe aktar"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Kişileri Google den içeriye aktar"

, "manage shared addressbooks"
: "Paylaşılan adres defterlerini yönet"

, "Create new shared addressbook folders"
: "Yeni paylaşılan adresdefteri klasörü oluştur."

, "manage shared addressbook favorites"
: "Sık kullanılan ortak adres defterlerini düzelt"

, "Create or update shared addressbook favorites"
: "Sık kullanılan ortak adres defteri kur veya düzelt"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "%s in özel adres defteri"

, "All contacts I have read grants for"
: "Okuma hakkına sahip olduğum kişiler"

, "My company"
: "Şirketim"

, "All coworkers in my company"
: "Şirketimdeki iş arkadaşlarım"

, "My contacts"
: "Kişilerim"

, "All contacts in my Addressbooks"
: "Rehberimdeki kişiler"

, "Last modified by me"
: "Son düzenlediğim"

, "All contacts that I have last modified"
: "Son düzenlediğim kişiler"

, "Internal Contacts"
: "Sistem içi kişiler"
, ""
: "Project-Id-Version: Tine 2.0 - GDPR\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: Turkish\nX-Poedit-Country: TURKEY\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=1; plural=0;\n"

, "Data provenances"
: ""

, "Data intended purposes"
: ""

, "Show expired"
: ""

, "Data Provenance"
: ""

, "Reason for Editing"
: ""

, "Please enter the reason for editing this data"
: ""

, "Please Confirm the Data Provenance"
: ""

, "GDPR"
: ""

, "Must not be contacted"
: ""

, "This Contact withdrawed usage of his data for any purpose."
: ""

, "Blacklist"
: ""

, "GDPR Intended Purpose"
: ""

, "GDPR Blacklisted"
: ""

, "GDPR Data Provenance"
: ""

, "GDPR Data Editing Reason"
: ""

, "Data provenance for ADB contacts mandatory"
: ""

, "Whether the data provenance for ADB contacts is mandatory, not mandatory or empty provenances will be set to a default"
: ""

, "yes"
: ""

, "no"
: ""

, "default"
: ""

, "Default data provenance for ADB contacts"
: ""

, "Data intended purpose, Data intended purposes"
: [
  ""

]
, "Agreement date"
: ""

, "Agreement comment"
: ""

, "Withdraw date"
: ""

, "Withdraw comment"
: ""

, "Data provenance, Data provenances"
: [
  ""

]
, "Expiration"
: ""

, "Manage data provenances in CoreData"
: ""

, "View, create, delete or update data provenances in CoreData application"
: ""

, "Manage data intended purposes in CoreData"
: ""

, "View, create, delete or update data intended purposes in CoreData application"
: ""

, "List"
: "one: Liste\n\nother: Listeler"

, "Addressbook"
: "one: Adres defteri\n\nother: Adres defterleri"

, "Contact"
: "one: Kişi\n\nother: Kişiler"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

, "Data intended purpose"
: ""

, "Data provenance"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
